pub struct MetadataManager<'a> { /* private fields */ }Implementations
Sourceimpl<'a> MetadataManager<'a>
impl<'a> MetadataManager<'a>
pub fn new( package_storage: &'a mut PackageStorage, metadata_storage: &'a mut MetadataStorage, ) -> Self
Sourcepub fn pin_package(&mut self, name: &str, reason: Option<String>) -> Result<()>
pub fn pin_package(&mut self, name: &str, reason: Option<String>) -> Result<()>
Pins a package to its current version, preventing automatic updates.
Sourcepub fn unpin_package(&mut self, name: &str) -> Result<()>
pub fn unpin_package(&mut self, name: &str) -> Result<()>
Unpins a package, allowing it to receive automatic updates.
Sourcepub fn remove_package(&mut self, name: &str) -> Result<()>
pub fn remove_package(&mut self, name: &str) -> Result<()>
Removes package metadata for a package without touching runtime artifacts.
Sourcepub fn rename_package(&mut self, old_name: &str, new_name: &str) -> Result<bool>
pub fn rename_package(&mut self, old_name: &str, new_name: &str) -> Result<bool>
Renames a package alias without changing provider/repo/version metadata.
Sourcepub fn set_key(
&mut self,
name: &str,
set_key: &str,
) -> Result<MetadataSetResult>
pub fn set_key( &mut self, name: &str, set_key: &str, ) -> Result<MetadataSetResult>
Sets a package metadata field using dot-notation key path. Example: “is_pinned=true” or “pattern=.x86_64.”
Sourcepub fn get_key(&self, name: &str, get_key: &str) -> Result<String>
pub fn get_key(&self, name: &str, get_key: &str) -> Result<String>
Gets a package metadata field using dot-notation key path. Example: “is_pinned” or “version”
Sourcepub fn set_bulk(
&mut self,
name: &str,
set_keys: &[String],
) -> MetadataBulkSetResult
pub fn set_bulk( &mut self, name: &str, set_keys: &[String], ) -> MetadataBulkSetResult
Sets multiple package metadata fields in bulk.
Sourcepub fn get_bulk(&self, name: &str, get_keys: &[String]) -> MetadataBulkGetResult
pub fn get_bulk(&self, name: &str, get_keys: &[String]) -> MetadataBulkGetResult
Gets multiple package metadata fields in bulk.